package network

import (
	"context"
	"fmt"
	"log"
	"os"
	"path/filepath"
	"time"

	"github.com/cretz/bine/tor"
)

// InitTorSession initialize a tor session
func InitTorSession() (t *tor.Tor, dialer *tor.Dialer, dialCancel context.CancelFunc, err error) {
	log.Println("Initializing hidden network ...")
	t, err = tor.Start(nil, nil)
	if err != nil {
		log.Panicf("Failed to start tor: %v", err)
	}
	// Wait at most 30 seconds to start network and get
	log.Println("Wait for network to initilize for 30 seconds ...")
	dialCtx, dialCancel := context.WithTimeout(context.Background(), time.Second*30)

	dialer, err = t.Dialer(dialCtx, nil)
	if err != nil {
		return
	}
	return
}

func CleanUp() {
	rm, err := filepath.Glob("data-dir*")
	if err != nil {
		log.Println(err)
	}
	for _, f := range rm {
		fmt.Printf("Removing %s\n", f)
		os.RemoveAll(f)
	}
}
